#
# spec file for package python-pikepdf
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%if 0%{?suse_version} < 1550 && 0%{?sle_version} > 150300
%bcond_with test
%endif
Name:           python-pikepdf
Version:        2.12.1
Release:        bp156.3.5
Summary:        Read and write PDFs with Python, powered by qpdf
License:        MPL-2.0
URL:            https://github.com/pikepdf/pikepdf
Source:         https://files.pythonhosted.org/packages/source/p/pikepdf/pikepdf-%{version}.tar.gz
## SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module Pillow >= 5.0.0}
BuildRequires:  %{python_module attrs >= 19.1.0}
BuildRequires:  %{python_module hypothesis >= 4.24}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest >= 4.4.0}
BuildRequires:  %{python_module pytest-helpers-namespace >= 2019.1.8}
BuildRequires:  %{python_module pytest-timeout >= 1.3.3}
BuildRequires:  %{python_module python-dateutil >= 1.4}
%endif
## /SECTION
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lxml >= 4.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pybind11 >= 2.6.0}
BuildRequires:  %{python_module pybind11-devel >= 2.6.0}
BuildRequires:  %{python_module setuptools_scm_git_archive}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libqpdf)
Requires:       python-Pillow >= 5.0.0
Requires:       python-lxml >= 4.0
%python_subpackages

%description
Read and write PDFs with Python, powered by qpdf.

%prep
%setup -q -n pikepdf-%{version}
# Simplify setup_requires
sed -i 's/setuptools >= [0-9]*/setuptools/;/wheel/d' setup.py
sed -i 's/setuptools_scm\[toml\] >= [0-9.]*/setuptools/g' setup.py
rm setup.cfg

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Ignore test_minimum_qpdf_version as it fails on Leap
# despite all other tests passing.
%if %{with test}
%pytest_arch -k 'not test_minimum_qpdf_version'
%endif

%files %{python_files}
%license LICENSE.txt licenses
%doc README.md docs/*/*.rst
%{python_sitearch}/pikepdf*

%changelog
* Fri Apr 22 2022 Max Lin <mlin@suse.com>
- Disable test on Leap 15.4
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12.1
  * Fixed documentation typo and updated precommit settings.
  * Ongoing improvements to code coverage: now related to image
    handling.
- Update to version 2.12.0
  * Complete bindings for ``pikepdf.Annotation`` (useful for
    interpreting PDF form widgets, comments, etc.)
  * Ongoing improvements to code coverage: minor bug fixes,
    unreachable code removal, more coverage.
- Update to version 2.11.4
  * Fix issue #160, 'Tried to call pure virtual function
    "TokenFilter::handle_token"'; this was a Python/C++
    reference counting problem.
- Update to version 2.11.3
  * Check for versions of jbig2dec that are too old to be
    supported (lacking the necessary command line arguments to
    extract an image from a PDF).
  * Fix setup.py typo: cmd_class changed to cmdclass.
* Fri Apr 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11.2
  * Added missing documentation for ``Pdf.is_encrypted``.
- Update to version 2.11.1
  * Fixed an issue with ``Object.emplace()`` not retaining the
    original object's /Parent.
* Wed Apr  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11.0
  * Add new functions: Pdf.generate_appearance_streams and
    Pdf.flatten_annotations, to support common work with PDF forms.
- Update to version 2.10.0
  * Fixed a XML External Entity (XXE) processing vulnerability in
    PDF XMP metadata parsing (CVE-2021-29421)
  * Bind new functions to check, when a PDF is opened, whether
    the password used to open the PDF matched the owner password,
    user password, or both: Pdf.user_password_matched and
    Pdf.owner_password_matched.
- Update to version 2.9.2
  * Further expansion of test coverage of several functions, and
    minor bug fixes along the way.
  * Improve parameter validation for some outline-related functions.
  * Fixed overloaded __repr__ functions in _methods.py not being
    applied.
- Update to version 2.9.1
  * Fixed function signatures for _repr_mimebundle_ functions to
    match IPython's spec.
  * Fixed some error messages regarding attempts to do strange
    things with pikepdf.Name, like pikepdf.Name.Foo = 3.
  * Eliminated code to handle an exception that provably does not
    occur.
- Update to version 2.9.0
  * We now issue a warning when attempting to use pikepdf.open
    on a bytes object where it could be either a PDF loaded into
    memory or a filename.
  * pikepdf.Page.label will now return the "ordinary" page number
    if no special rules for pages are defined.
  * Many improvements to tests and test coverage.
  * An obsolete private function Object._roundtrip was removed.
* Thu Mar  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.0
  * Fixed an issue with extracting data from images that had their
    DecodeParms structured as a list of dictionaries.
  * Fixed an issue where a dangling stream object is created if we
    fail to create the requested stream dictionary.
  * Calling Dictionary() and Array() on objects which are already
    of that type returns a shallow copy rather than throwing an
    exception, in keeping with Python semantics.
- Update to version 2.7.0
  * Added an option to tell Pdf.save to recompress flate streams,
    and a global option to set the flate compression level. This
    option can be use to force the recompression of flate streams
    if they are not well compressed.
  * Fixed "TypeError: only pages can be inserted" when attempting
    to an insert an unowned page using QPDF 10.2.0 or later.
- Update to version 2.6.0
  * Rebuild wheels against QPDF 10.2.0.
* Sun Feb  7 2021 John Vandenberg <jayvdb@gmail.com>
- Add docs/*/*.rst to package contents
- Update to v2.5.2
  * See https://github.com/pikepdf/pikepdf/blob/master/docs/release_notes.rst
* Fri Jul 31 2020 Karl Cheng <qantas94heavy@gmail.com>
- Update pikepdf to 1.17.3
- Allow test_object.py to run in package spec
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in python2 package on py3 only software
* Sun Apr 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.11.1
  * We now avoid creating an empty XMP metadata entry when files
    are saved.
  * Updated documentation to describe how to delete the document
    information dictionary.
- Update to version 1.11.0
  * Prevent creation of dictionaries with invalid names (not
    beginning with /).
  * Allow pikepdf's build to specify a qpdf source tree, allowing
    one to compile pikepdf against an unreleased/modified version
    of qpdf.
  * Improved behavior of pages.p() and pages.remove() when
    invalid parameters were given.
  * Fixed compatibility with libqpdf version 10.0.1, and build
    official wheels against this version.
  * Fixed compatibility with pytest 5.x.
  * Fixed the documentation build.
  * Fixed an issue with running tests in a non-Unicode locale.
  * Fixed a test that randomly failed due to a "deadline error".
  * Removed a possibly nonfree test file.
- Update to version 1.10.4
  * Rebuild Python wheels with newer version of libqpdf. Fixes
    problems with opening certain password-protected files (#87)
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 1.10.3
  * Fixed ``isinstance(obj, pikepdf.Operator)`` not working. (#86)
  * Documentation updates.
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.10.2
  * Fixed an issue where pages added from a foreign PDF were added as references
    rather than copies.
  * Documentation updates.
* Fri Feb 14 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.10.1
